@@ -66,7 +66,10 @@ setMethod(
 #' \item{\strong{AWS_EXPIRATION:} is equivalent to the \code{dbConnect} parameter - \code{duration_seconds}}
 #' \item{\strong{AWS_ATHENA_S3_STAGING_DIR:} is equivalent to the \code{dbConnect} parameter - \code{s3_staging_dir}}
 #' \item{\strong{AWS_ATHENA_WORK_GROUP:} is equivalent to \code{dbConnect} parameter - \code{work_group}}
+#' \item{\strong{AWS_REGION:} is equivalent to \code{dbConnect} parameter - \code{region_name}}
 #' }
+#' 
+#' \strong{NOTE:} If you have set any environmental variables in \code{.Renviron} please restart your R in order for the changes to take affect.
 #'
 #' @inheritParams DBI::dbConnect
 #' @param aws_access_key_id AWS access key ID
@@ -169,14 +172,18 @@ setMethod(
     aws_session_token <- aws_session_token %||% get_aws_env("AWS_SESSION_TOKEN")
     role_arn <- role_arn %||% get_aws_env("AWS_ROLE_ARN")
     work_group <- work_group %||% get_aws_env("AWS_ATHENA_WORK_GROUP")
+    region_name <- region_name %||% get_aws_env("AWS_REGION")
     
+    # if aws session token then return duration
     aws_expiration <- NULL
+    if(!is.null(aws_session_token)) aws_expiration <- get_aws_env("AWS_EXPIRATION")
+    if(!is.null(aws_expiration)) aws_expiration <- as.POSIXct(as.numeric(aws_expiration), origin='1970-01-01')
     if(!is.null(role_arn)) {
       creds <- assume_role(profile_name = profile_name,
                            region_name = region_name,
                            role_arn = role_arn,
                            role_session_name = role_session_name,
-                           duration_seconds = duration_seconds %||% get_aws_env("AWS_EXPIRATION"))
+                           duration_seconds = duration_seconds)
       profile_name <- NULL
       aws_access_key_id <- creds$AccessKeyId
       aws_secret_access_key <- creds$SecretAccessKey
