@@ -9,8 +9,11 @@ AthenaResult <- function(conn,
   Athena <- client_athena(conn)
   Request <- request(conn, statement)
   
-  tryCatch(response <- do.call(Athena$start_query_execution, Request, quote = T),
-           error = function(e) py_error(e))
+  response <- list(QueryExecutionId = NULL)
+  if (athena_option_env$cache_size > 0) response <- list(QueryExecutionId = check_cache(statement, conn@info$work_group))
+  if (is.null(response$QueryExecutionId)) {
+    tryCatch(response <- list(QueryExecutionId = do.call(Athena$start_query_execution, Request, quote = T)$QueryExecutionId),
+             error = function(e) py_error(e))}
   on.exit(if(!is.null(conn@info$expiration)) time_check(conn@info$expiration))
   new("AthenaResult", connection = conn, athena = Athena, info = response)
 }
@@ -88,11 +91,13 @@ setMethod(
       eval.parent(substitute(res@connection@ptr <- NULL))
       eval.parent(substitute(res@athena <- NULL))
       
-      # Out put Python error as warning if s3 resource can't be dropped
-      tryCatch(s3$Object(s3_info$bucket, paste0(result_info$key, ".metadata"))$delete(),
-               error = function(e) py_warning(e))
-      tryCatch(s3$Object(s3_info$bucket, result_info$key)$delete(),
-               error = function(e) cat(""))
+      # for caching s3 data is still required
+      if (athena_option_env$cache_size == 0){
+        # Out put Python error as warning if s3 resource can't be dropped
+        tryCatch(s3$Object(s3_info$bucket, paste0(result_info$key, ".metadata"))$delete(),
+                 error = function(e) py_warning(e))
+        tryCatch(s3$Object(s3_info$bucket, result_info$key)$delete(),
+                 error = function(e) cat(""))}
     }
     invisible(TRUE)
   })
@@ -137,6 +142,9 @@ setMethod(
     # check status of query
     result <- poll(res)
     
+    # cache query metadata if caching is enabled
+    if (athena_option_env$cache_size > 0) cache_query(result)
+    
     result_info <- split_s3_uri(result$QueryExecution$ResultConfiguration$OutputLocation)
     
     # if query failed stop
