@@ -23,13 +23,13 @@ db_desc.AthenaConnection <- function(x) {
 #' @param ... passes \code{RAthena} table creation parameters: [\code{file_type},\code{s3_location},\code{partition}]
 #' \itemize{
 #'          \item{\code{file_type:} What file type to store data.frame on s3, RAthena currently supports ["NULL","csv", "parquet", "json"]. 
-#'                        \code{"NULL"} will let athena set the file_type for you.}
+#'                        \code{"NULL"} will let Athena set the file_type for you.}
 #'          \item{\code{s3_location:} s3 bucket to store Athena table, must be set as a s3 uri for example ("s3://mybucket/data/")}
 #'          \item{\code{partition:} Partition Athena table, requires to be a partitioned variable from previous table.}}
 #' @name db_compute
 #' @return
-#' db_compute returns table name
-#' @seealso \code{\link{db_save_query}}
+#' \code{db_compute} returns table name
+#' @seealso \code{\link{backend_dbplyr}}
 #' @examples 
 #' \dontrun{
 #' # Note: 
@@ -50,11 +50,11 @@ db_desc.AthenaConnection <- function(x) {
 #' athena_mtcars <- tbl(con, "mtcars")
 #' mtcars_filter <- athena_mtcars %>% filter(gear >=4)
 #' 
-#' # create athena with unique table name
+#' # create Athena with unique table name
 #' mtcars_filer %>% 
 #'   compute()
 #' 
-#' # create athena with specified name and s3 location
+#' # create Athena with specified name and s3 location
 #' mtcars_filer %>% 
 #'     compute("mtcars_filer",
 #'             s3_location = "s3://mybucket/mtcars_filer/")
@@ -67,26 +67,39 @@ db_compute.AthenaConnection <- function(con,
                                         sql,
                                         ...) {
   db_save_query <- pkg_method("db_save_query", "dplyr")
+  in_schema <- pkg_method("in_schema", "dbplyr")
+  
   table <- db_save_query(con, sql, table, ...)
-  table
+  if (grepl("\\.", table)) {
+    schema <- gsub("\\..*", "" , table)
+    table <- gsub(".*\\.", "" , table)
+  } else {
+    schema <- con@info$dbms.name
+    table <- table}
+  
+  in_schema(schema, table)
 }
 
-#' S3 implementation of \code{db_save_query} for Athena
+#' Athena S3 implementation of dbplyr backend functions
 #' 
-#' This is a backend method for dplyr function \code{db_save_query} to creating tables from \code{tbl} using \code{compute} function.
-#' Users won't be required to access and run this function. However users may find it useful to know the extra
-#' parameters \code{db_save_query} provided for \code{compute} function.
+#' These functions are used to build the different types of SQL queries. 
+#' The AWS Athena implementation give extra parameters to allow access the to standard DBI Athena methods. They also
+#' utilise AWS Glue to speed up sql query execution.
 #' @param con A \code{\link{dbConnect}} object, as returned by \code{dbConnect()}
-#' @param sql SQL code to be sent to the data
-#' @param name Table name if left default RAthena will use default from 'dplyr''s \code{compute} function.
-#' @param file_type What file type to store data.frame on s3, RAthena currently supports ["NULL","csv", "parquet", "json"]. 
-#'                  \code{"NULL"} will let athena set the file_type for you.
+#' @param sql SQL code to be sent to AWS Athena
+#' @param name Table name if left default noctua will use default from 'dplyr''s \code{compute} function.
+#' @param file_type What file type to store data.frame on s3, noctua currently supports ["NULL","csv", "parquet", "json"]. 
+#'                  \code{"NULL"} will let Athena set the file_type for you.
 #' @param s3_location s3 bucket to store Athena table, must be set as a s3 uri for example ("s3://mybucket/data/")
 #' @param partition Partition Athena table, requires to be a partitioned variable from previous table.
 #' @param ... other parameters, currently not implemented
-#' @name db_save_query
+#' @name backend_dbplyr
 #' @return
-#' db_save_query returns table name
+#' \describe{
+#' \item{db_save_query}{Returns table name}
+#' \item{db_explain}{Raises an \code{error} as AWS Athena does not support \code{EXPLAIN} queries \href{https://docs.aws.amazon.com/athena/latest/ug/other-notable-limitations.html}{Athena Limitations}}
+#' \item{db_query_fields}{Returns sql query column names}
+#' }
 db_save_query.AthenaConnection <- function(con, sql, name , 
                                            file_type = c("NULL","csv", "parquet", "json"),
                                            s3_location = NULL,
@@ -213,4 +226,49 @@ db_copy_to.AthenaConnection <- function(con, table, values,
   table
 }
 
+#' @rdname backend_dbplyr
+db_explain.AthenaConnection <- function(con, sql, ...){
+  # AWS Athena does not support Explain statements https://docs.aws.amazon.com/athena/latest/ug/other-notable-limitations.html
+  stop("Athena does not support EXPLAIN statements.", call. = FALSE)
+}
 
+#' @rdname backend_dbplyr
+db_query_fields.AthenaConnection <- function(con, sql, ...) {
+  
+  # check if sql is dbplyr ident
+  is_ident <- inherits(sql, "ident")
+  
+  if(is_ident) { # If ident, get the fields from Glue
+    
+    if (grepl("\\.", sql)) {
+      dbms.name <- gsub("\\..*", "" , sql)
+      Table <- gsub(".*\\.", "" , sql)
+    } else {
+      dbms.name <- con@info$dbms.name
+      Table <- sql}
+    
+    glue <- con@ptr$client("glue")
+    
+    tryCatch(
+      output <- glue$get_table(DatabaseName = dbms.name,
+                               Name = Table)$Table,
+      error = function(e) py_error(e))
+    
+    col_names = vapply(output$StorageDescriptor$Columns, function(y) y$Name, FUN.VALUE = character(1))
+    partitions = vapply(output$PartitionKeys,function(y) y$Name, FUN.VALUE = character(1))
+    
+    c(col_names, partitions)
+  } else { # If a subquery, query Athena for the fields
+    # return dplyr methods
+    sql_select <- pkg_method("sql_select", "dplyr")
+    sql_subquery <- pkg_method("sql_subquery", "dplyr")
+    dplyr_sql <- pkg_method("sql", "dplyr")
+    
+    sql <- sql_select(con, dplyr_sql("*"), sql_subquery(con, sql), where = dplyr_sql("0 = 1"))
+    qry <- dbSendQuery(con, sql)
+    on.exit(dbClearResult(qry))
+    
+    res <- dbFetch(qry, 0)
+    names(res)
+  }
+}
