@@ -30,23 +30,63 @@ DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
   `y` STRING
 )
 ROW FORMAT DELIMITED
-	FIELDS TERMINATED BY '\t'
+	FIELDS TERMINATED BY ','
 	LINES TERMINATED BY ", gsub("_","","'\\_n'"),
            "\nLOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'
-TBLPROPERTIES (\"skip.header.line.count\"=\"1\");")), 
+TBLPROPERTIES (\"skip.header.line.count\"=\"1\",
+\t\t'compressionType'='gzip');")),
 tbl3 = 
-  DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
+DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
+  `x` INT,
+  `y` STRING
+)
+ROW FORMAT DELIMITED
+\tFIELDS TERMINATED BY '	'
+\tLINES TERMINATED BY ", gsub("_","","'\\_n'"),"
+LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'
+TBLPROPERTIES (\"skip.header.line.count\"=\"1\");")),
+tbl4 = 
+DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
+  `x` INT,
+  `y` STRING
+)
+ROW FORMAT DELIMITED
+\tFIELDS TERMINATED BY '	'
+\tLINES TERMINATED BY ", gsub("_","","'\\_n'"),"
+LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'
+TBLPROPERTIES (\"skip.header.line.count\"=\"1\",
+\t\t'compressionType'='gzip');")), 
+tbl5 = 
+DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
   `x` INT,
   `y` STRING
 )
 STORED AS PARQUET
 LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'\n;")),
-tbl4 = 
-  DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (\n  `x` INT,\n  `y` STRING\n)
+tbl6 = 
+DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
+  `x` INT,
+  `y` STRING
+)
 PARTITIONED BY (timestamp STRING)
 STORED AS PARQUET
-LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'\n;")))
-
+LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'
+tblproperties (\"parquet.compress\"=\"SNAPPY\");")),
+tbl7 = 
+DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
+  `x` INT,
+  `y` STRING
+)
+ROW FORMAT  serde 'org.apache.hive.hcatalog.data.JsonSerDe'
+LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'\n")),
+tbl8 = 
+  DBI::SQL(paste0("CREATE EXTERNAL TABLE `default`.`test_df` (
+  `x` INT,
+  `y` STRING
+)
+PARTITIONED BY (timestamp STRING)
+ROW FORMAT  serde 'org.apache.hive.hcatalog.data.JsonSerDe'
+LOCATION '",Sys.getenv("rathena_s3_tbl"),"default/test_df/'\n")))
 
 # static Athena Query Request Tests
 athena_test_req1 <-
@@ -70,7 +110,8 @@ athena_test_req3 <-
 athena_test_req4 <-
   list(QueryString = "select * from test_query",
        QueryExecutionContext = list(Database = "default"),
-       ResultConfiguration = list(OutputLocation = Sys.getenv("rathena_s3_query")))
+       ResultConfiguration = list(OutputLocation = Sys.getenv("rathena_s3_query")),
+       WorkGroup = "primary")
 
 # static s3 path location
 s3_loc <- list(exp_s3_1 = "path/to/file/test/dummy_file/dummy_file.csv",
@@ -78,4 +119,8 @@ s3_loc <- list(exp_s3_1 = "path/to/file/test/dummy_file/dummy_file.csv",
                exp_s3_3 = c("path/to/test/dummy_file/YEAR=2000/dummy_file_1.tsv", "path/to/test/dummy_file/YEAR=2000/dummy_file_2.tsv"),
                exp_s3_4 = c("path/to/test/dummy_file/YEAR=2000/dummy_file_1.tsv.gz","path/to/test/dummy_file/YEAR=2000/dummy_file_2.tsv.gz"),
                exp_s3_5 = "path/to/test/dummy_file/dummy_file.parquet",
-               exp_s3_6 = "path/to/dummy_file/YEAR=2000/dummy_file.snappy.parquet")
\ No newline at end of file
+               exp_s3_6 = "path/to/dummy_file/YEAR=2000/dummy_file.snappy.parquet",
+               exp_s3_7 = "path/to/test/dummy_file/dummy_file.json",
+               exp_s3_8 = "path/to/dummy_file/YEAR=2000/dummy_file.json")
+
+show_ddl <- SQL('CREATE EXTERNAL TABLE `default.test_df`(\n  `w` timestamp, \n  `x` int, \n  `y` string, \n  `z` boolean)\nPARTITIONED BY ( \n  `timestamp` string)\nROW FORMAT DELIMITED \n  FIELDS TERMINATED BY \'\\t\' \n  LINES TERMINATED BY \'\\n\' \nSTORED AS INPUTFORMAT \n  \'org.apache.hadoop.mapred.TextInputFormat\' \nOUTPUTFORMAT \n  \'org.apache.hadoop.hive.ql.io.HiveIgnoreKeyTextOutputFormat\'\nLOCATION\n  \'s3://test-rathena/default/test_df\'\nTBLPROPERTIES (\n  \'skip.header.line.count\'=\'1\')')
